@@ -55,6 +55,8 @@ my $configure_gnusocial=sub {
    my $site_profile=$_[8]||'';
    my $site_build=$_[9]||'';
    $service_and_cert_password=$_[10]||'';
+   my $twitter_api_key=$_[11]||'';
+   my $twitter_api_sec=$_[12]||'';
    if ($site_profile=~/Commmunity/) {
       $site_profile='community';
    } elsif ($site_profile=~/Public/) {
@@ -744,8 +746,8 @@ END
          'dbusername' => 'gnusocial',
          'dbpassword' => $service_and_cert_password,
          'admin_nickname' => 'admin',
-         'admin_password' => 'admin',
-         'admin_password2' => 'admin',
+         'admin_password' => $service_and_cert_password,
+         'admin_password2' => $service_and_cert_password,
          'admin_email' => $verified_email,
          'site_profile' => $site_profile,
          'submit' => 'Submit'
@@ -868,6 +870,20 @@ END
 #END
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}echo -e \"$config_email\" >> /var/www/gnusocial/config.php");
+   if ($twitter_api_key) {
+      my $config_twitter=<<END;
+addPlugin(
+   'TwitterBridge',
+   array(
+      'consumer_key'    => \'$twitter_api_key\',
+      'consumer_secret' => \'$twitter_api_sec\'
+   )
+);
+\\x24config['integration']['source'] = \'$site_name\';
+END
+      ($stdout,$stderr)=$handle->cmd(
+         "${sudo}echo -e \"$config_twitter\" >> /var/www/gnusocial/config.php");
+   }
    ($stdout,$stderr)=$handle->cmd(
       "php /var/www/gnusocial/scripts/checkschema.php");
    print "\n   ACCESS GNU SOCIAL UI AT:\n\n",
@@ -922,6 +938,8 @@ my $standup_gnusocial=sub {
    my $site_profile="]T[{choose_site_profile}";
    my $site_build="]T[{choose_build}";
    my $strong_password="]I[{'gnusocial_enter_password',1}";
+   my $twitter_api_key="]I[{'gnusocial_twitter_api',1}";
+   my $twitter_api_sec="]I[{'gnusocial_twitter_api',2}";
    #if (-1<index $site_name, ']T[') {
    #   $site_name="]I[{'gnusocial_enter_domain_name',1}"; 
    #}
@@ -975,14 +993,14 @@ my $standup_gnusocial=sub {
          launch_server('GNU.io/Social',$cnt,$gnusocial,'',$c,
          $configure_gnusocial,'',$region,$verified_email,
          $permanent_ip,$site_name,$site_profile,$site_build,
-         $strong_password);
+         $strong_password,$twitter_api_key,$twitter_api_sec);
       } else {
          my $num=$#{$main::aws->{'GNU.io/Social'}}-1;
          foreach my $num (0..$num) {
             launch_server('GNU.io/Social',$cnt++,$gnusocial,'',$c,
             $configure_gnusocial,'',$region,$verified_email,
             $permanent_ip,$site_name,$site_profile,$site_build,
-            $strong_password);
+            $strong_password,$twitter_api_key,$twitter_api_sec);
          }
       }
    }
@@ -1286,7 +1304,11 @@ END
    to apply for a "limit increase". A limit increase will also remove the
    requirement that recipients be Amazon verified. Note - there is *NO*
    guarantee that Amazon will lift email restrictions for any particular
-   user. Use this link to apply for a limit increase:
+   user. Use the link below to apply for a limit increase.
+
+   NOTE: If using the FullAuto Windows App, you will have to expand this box
+         to fullscreen and hit enter, and then re-enter this screen in order
+         to see the entire URL listed below. Link is clickable if underlined.
 
    http://docs.aws.amazon.com/ses/latest/DeveloperGuide/request-production-access.html
 END
@@ -1324,7 +1346,7 @@ END
    a link to inform Amazon if the email was "unwanted". Once they are verified,
    you can successfully send an invite to them from your GNU Social server.
 
-   http://docs.aws.amazon.com/ses/latest/DeveloperGuide/verify-email-addresses.html
+http://docs.aws.amazon.com/ses/latest/DeveloperGuide/verify-email-addresses.html
 END
    my $use_limited_email={
 
@@ -1479,16 +1501,16 @@ END
       last if $word;
    }
    $gnusocial_password_banner.=<<END;
-   Database (MariaDB), Web Server (NGINX) and SSL Certificate need a strong
-   password. Use the one supplied here, or create your own. To create
-   your own, use the [DEL] key to clear the highlighted input box first.
+   Database (MariaDB), Web Server (NGINX) and SSL Certificate and "admin"
+   GNU Social account all need a strong password. Use the one supplied here,
+   or create your own. To create your own, use the [DEL] key to clear the
+   highlighted input box first.
 
    *** BE SURE TO WRITE IT DOWN AND KEEP IT SOMEWHERE SAFE! ***
 
    Input box with === border is highlighted (active) input box.
    Use [TAB] key to switch focus between input boxes.
 
-
    Password
                     ]I[{1,\'$word\',50}
 
@@ -1612,19 +1634,41 @@ END
 
 };
 
-our $gnusocial_enter_twitter_creds=sub {
-
-   my $twitter_creds_banner=<<'END';
+our $gnusocial_enter_twitter_api=sub {
 
+   my $twitter_api_banner=<<'END';
+    ___     _             _  __             _     ___                 _
+   | __|_ _| |_ ___ _ _  | |/ /___ _  _   _| |_  / __| ___ __ _ _ ___| |_
+   | _|| ' \  _/ -_) '_| | ' </ -_) || | |_   _| \__ \/ -_) _| '_/ -_)  _|
+   |___|_||_\__\___|_|   |_|\_\___|\_, |   |_|   |___/\___\__|_| \___|\__|
+                                   |__/
 END
-   my $gnusocial_twitter_creds={
+   $twitter_api_banner.=<<END;
 
-      Name => 'gnusocial_twitter_creds',
+   On twitter page showing bold "]I[{'gnusocial_enter_site_name',1}", there
+   are tabs just underneath. Go to Keys and Access Tokens tab:
+                      ________________________
+                     |                        |                + Use [TAB] to
+   Details  Settings | Keys and Access Tokens | Permissions    + switch boxes
+  ___________________|                        |________________________________
+
+   Copy & Paste (or Type) into input boxes the needed API Key & API Secret:
+
+   Consumer Key (API Key)  
+                          ]I[{1,'',52}
+   Consumer Secret
+   (API Secret)
+                   ]I[{2,'',59}
+END
+   my $gnusocial_twitter_api={
+
+      Name => 'gnusocial_twitter_api',
+      Input => 1,
       Result => $gnusocial_setup_summary,
-      Banner => $twitter_creds_banner,
+      Banner => $twitter_api_banner,
 
    };
-   return $gnusocial_twitter_creds;
+   return $gnusocial_twitter_api;
 
 };
 
@@ -1632,7 +1676,14 @@ our $gnusocial_enter_values=sub {
 
    package gnusocial_enter_values;
    my $permanent_ip="]T[{permanent_ip}";
-   unless ($permanent_ip=~s/^.*Elastic.* (\d+\.\d+\.\d+\.\d+).*$/$1/s) {
+   if ($permanent_ip=~/Allocate/) {
+      my $c="aws ec2 allocate-address --domain vpc";
+      my ($hash,$output,$error)=
+            &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+      $hash||={};
+      $permanent_ip=$main::aws->{permanent_ip}=$hash->{PublicIp};
+   } elsif ($permanent_ip=~s/^.*Elastic.* (\d+\.\d+\.\d+\.\d+).*$/$1/s) {
+   } else {
       STDOUT->autoflush(1);
       print "\n   ERROR: You must use an Elastic IP for twitter bridge!";
       sleep 5;
@@ -1640,11 +1691,10 @@ our $gnusocial_enter_values=sub {
       return '{permanent_ip}<';
    }
    my $enter_values_banner=<<'END';
-    ___     _             _____ _                 __   __    _               _
-   | __|_ _| |_ ___ _ _  |_   _| |_  ___ ___ ___  \ \ / /_ _| |_  _ ___ ___ (_)
-   | _|| ' \  _/ -_) '_|   | | | ' \/ -_|_-</ -_)  \ V / _` | | || / -_|_-<  _
-   |___|_||_\__\___|_|     |_| |_||_\___/__/\___|   \_/\__,_|_|\_,_\___/__/ (_)
-
+   ___     _             _____ _                 __   __    _               _
+  | __|_ _| |_ ___ _ _  |_   _| |_  ___ ___ ___  \ \ / /_ _| |_  _ ___ ___ (_)
+  | _|| ' \  _/ -_) '_|   | | | ' \/ -_|_-</ -_)  \ V / _` | | || / -_|_-<  _
+  |___|_||_\__\___|_|     |_| |_||_\___/__/\___|   \_/\__,_|_|\_,_\___/__/ (_)
 
 END
    $enter_values_banner.=<<END;
@@ -1657,12 +1707,17 @@ END
 
    Callback URL -->  https://$permanent_ip/twitter/authorization
 
+   -----------------------------------------------------------------
+
+   * Read and check the "Twitter Developer Agreement" checkbox.
+
+     Click on "Create your Twitter application".
 END
    my $enter_values={
 
       Name => 'enter_values',
       Result => 
-   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_twitter_creds,
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_twitter_api,
       Banner => $enter_values_banner,
 
    };
@@ -1674,22 +1729,23 @@ our $gnusocial_twitter_app=sub {
 
    my $twitter_app_banner=<<'END';
 
-     ___              _         _          _ _   _               _
-    / __|_ _ ___ __ _| |_ ___  | |___ __ _(_) |_| |_ ___ _ _    /_\  _ __ _ __
-   | (__| '_/ -_) _` |  _/ -_) |  _\ V  V / |  _|  _/ -_) '_|  / _ \| '_ \ '_ \
-    \___|_| \___\__,_|\__\___|  \__|\_/\_/|_|\__|\__\___|_|   /_/ \_\ .__/ .__/
+    ___              _         _          _ _   _               _
+   / __|_ _ ___ __ _| |_ ___  | |___ __ _(_) |_| |_ ___ _ _    /_\  _ __ _ __
+  | (__| '_/ -_) _` |  _/ -_) |  _\ V  V / |  _|  _/ -_) '_|  / _ \| '_ \ '_ \
+   \___|_| \___\__,_|\__\___|  \__|\_/\_/|_|\__|\__\___|_|   /_/ \_\ .__/ .__/
                                                                     |_|  |_|
 
 END
    $twitter_app_banner.=<<END;
-   In your favorite browser, make sure you are first logged in with the twitter
-   account you intend to use for the twitter bridge. Then, navigate to this URL:
+   In your favorite browser, make sure you are first logged in with the
+   twitter account you intend to use for the twitter bridge. Then, navigate
+   to this URL:
 
    https://apps.twitter.com/app/new
 
    You will see a page with a number of input boxes asking for very specific
-   information. Press [ENTER] and the next screen of this setup will give you
-   values to cut and paste into those input boxes.
+   information. Press [ENTER] and the next screen of this setup will give 
+   you values to cut and paste into those input boxes.
 END
    my $twitter_app={
 
@@ -1764,7 +1820,8 @@ END
       Name => 'setting_up_bridge',
       Item_1 => {
          Text => 'I have a twitter account',
-         Result => $gnusocial_setup_summary,
+         Result => 
+            $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_twitter_app,
       },
       Item_2 => {
          Text => 'I do NOT have a twitter account',
@@ -1976,8 +2033,6 @@ our $gnusocial_enter_site_name=sub {
 END
    $gnusocial_site_banner.=<<END;
 
-   Input box with === border is highlighted (active) input box.
-   Use [TAB] key to switch focus between input boxes.
    Use [DEL] key to clear entire entry in highlighted input box.
    Use [Backspace] to backspace in highlighted input box.
 
